@@ -1,6 +1,6 @@
 /*
     misc
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -205,6 +205,154 @@ misc_scroll_window (GtkWidget  *widget,
 }
 
 
+/******************************************************************************
+*                                                                             *
+* ja:メニュー/ツールバー関数群                                                *
+*                                                                             *
+******************************************************************************/
+/*  ja:メニューを作成する
+        entries,メニュー構造体
+    accel_group,アクセルグループ                                            */
+void
+misc_create_menu (MiscCreateMenuEntry *entries,
+                  GtkAccelGroup       *accel_group)
+{
+  gint i;
+
+  for (i = 0; entries[i].menu_type != MISC_CREATE_MENU_TERMINAL; i++)
+    switch (entries[i].menu_type)
+      {
+        case MISC_CREATE_MENU_BAR:
+          entries[i].widget = gtk_menu_bar_new ();
+          break;
+        case MISC_CREATE_MENU_SHELL:
+          {
+            gchar *path, *p;
+            gint j;
+
+            entries[i].widget = gtk_menu_new ();
+            path = g_strdup (entries[i].path);
+            p = g_strrchr (path, '/');
+            *p = '\0';
+            for (j = 0; j < i; j++)
+              if (g_strcmp (entries[j].path, path) == 0)
+                {
+                  gtk_menu_item_set_submenu (GTK_MENU_ITEM (entries[j].widget),
+                                                            entries[i].widget);
+                  break;
+                }
+            g_free (path);
+          }
+          break;
+        case MISC_CREATE_MENU_ITEM:
+        case MISC_CREATE_MENU_SEPARATOR:
+          {
+            gchar *path, *p;
+            gint j;
+
+            entries[i].widget = entries[i].name
+                        ? gtk_menu_item_new_with_mnemonic (_(entries[i].name))
+                        : gtk_separator_menu_item_new ();
+            path = g_strdup (entries[i].path);
+            p = g_strrchr (path, '/') + 1 ;
+            *p = '\0';
+            for (j = 0; j < i; j++)
+              if (g_strcmp (entries[j].path, path) == 0)
+                {
+                  gtk_menu_shell_append (GTK_MENU_SHELL (entries[j].widget),
+                                                            entries[i].widget);
+                  break;
+                }
+            g_free (path);
+            if (accel_group && entries[i].accel)
+              {
+                guint key;
+                GdkModifierType mods;
+
+                gtk_accelerator_parse (entries[i].accel, &key, &mods);
+                gtk_widget_add_accelerator (entries[i].widget, "activate",
+                                        accel_group, key, mods,
+                                        GTK_ACCEL_VISIBLE | GTK_ACCEL_LOCKED);
+              }
+            if (entries[i].func)
+              g_signal_connect (G_OBJECT (entries[i].widget), "activate",
+                        G_CALLBACK (entries[i].func), entries[i].user_data);
+          }
+      }
+}
+
+
+/*  ja:メニューを検索する
+    entries,メニュー構造体
+       path,パス
+        RET,メニューアイテム                                                */
+GtkWidget *
+misc_find_menu (MiscCreateMenuEntry *entries,
+                const gchar         *path)
+{
+  gint i;
+
+  for (i = 0; entries[i].menu_type != MISC_CREATE_MENU_TERMINAL; i++)
+    if (g_strcmp (entries[i].path, path) == 0)
+      return entries[i].widget;
+  return NULL;
+}
+
+
+/*  ja:ツールバーを作成する
+    entries,ツールバー構造体
+        RET,ツールバー                                                      */
+GtkWidget *
+misc_create_toolbar (MiscCreateToolbarEntry *entries)
+{
+  gint i;
+  GtkWidget *toolbar;
+
+  toolbar = gtk_toolbar_new ();
+  gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
+                                                GTK_ORIENTATION_HORIZONTAL);
+  gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
+  for (i = 0; entries[i].path; i++)
+    {
+      if (entries[i].name)
+        {
+          GdkPixbuf *pixbuf;
+
+          pixbuf = gdk_pixbuf_new_from_xpm_data (entries[i].xpm);
+          entries[i].tool_item = gtk_tool_button_new
+                    (gtk_image_new_from_pixbuf (pixbuf), _(entries[i].name));
+          g_object_unref (pixbuf);
+          if (entries[i].func)
+            g_signal_connect (G_OBJECT (entries[i].tool_item), "clicked",
+                        G_CALLBACK (entries[i].func), entries[i].user_data);
+        }
+      else
+        {
+          entries[i].tool_item = gtk_separator_tool_item_new ();
+        }
+      gtk_toolbar_insert (GTK_TOOLBAR (toolbar), entries[i].tool_item, i);
+    }
+  return toolbar;
+}
+
+
+/*  ja:ツールバーを検索する
+    entries,ツールバー構造体
+       path,パス
+        RET,ツールアイテム                                                  */
+GtkToolItem *
+misc_find_toolbar (MiscCreateToolbarEntry *entries,
+                   const gchar            *path)
+{
+  gint i;
+
+  for (i = 0; entries[i].path; i++)
+    if (g_strcmp (entries[i].path, path) == 0)
+      return entries[i].tool_item;
+  return NULL;
+}
+
+
 /******************************************************************************
 *                                                                             *
 * ja:数値文字列関数群                                                         *
