@@ -33,12 +33,6 @@ extern "C" {
 * ja:ファイル関数群                                                           *
 *                                                                             *
 ******************************************************************************/
-/*  ja:ファイルの履歴に加える
-    file,ファイル名                                                         */
-void
-file_set_history (const gchar *file);
-
-
 /*  ja:TXTファイルを開く
      file,ファイル名
     tmaid,ウインドウ情報                                                 */
