@@ -451,7 +451,7 @@ find_dialog (FindString *fd)
     gtk_combo_box_append_text (GTK_COMBO_BOX (combo), find_text[i]);
   if (find_num > 0)
     {
-      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo)->child), find_text[0]);
+      gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
       gtk_editable_select_region (GTK_EDITABLE (GTK_BIN (combo)->child),
                                                                         0, -1);
     }
