@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#ifndef __FTYPE_H__
-#define __FTYPE_H__
+#ifndef __FORMAT_H__
+#define __FORMAT_H__
 
 
 #include "tmaid.h"
@@ -30,13 +30,14 @@ extern "C" {
 
 /******************************************************************************
 *                                                                             *
-* ja:ファイルタイプ選択ダイアログ関数群                                       *
+* ja:ファイルタイプダイアログ関数群                                           *
 *                                                                             *
 ******************************************************************************/
-/*  ja:ファイルタイプ選択ダイアログ表示
-    pos,選択されたファイルタイプ
-    RET,TRUE:OK,FALSE:Cancel                                                */
-gboolean ftype_dialog(gint *pos);
+/*  ja:ファイルタイプダイアログを表示する
+    ind,TRUE:独立ファイルタイプあり,FALSE:なし
+    RET,選択されたファイルタイプ(ftnum:独立,-1:キャンセル)                  */
+gint
+ftype_dialog (gboolean ind);
 
 
 #ifdef __cplusplus
