@@ -26,12 +26,12 @@
 
 /******************************************************************************
 *                                                                             *
-* ja:״ؿ                                                           *
+* ja:ジャンプ関数群                                                           *
 *                                                                             *
 ******************************************************************************/
-/*  ja:Ԥذư
-    tmaid,TXTɥ
-     line,(1...)                                                    */
+/*  ja:指定行へ移動
+    tmaid,TXTウインドウ情報
+     line,新しい行(1...)                                                    */
 void
 jump_operation (TmaidWindow *tmaid,
                 const gint   line)
@@ -85,14 +85,14 @@ jump_operation (TmaidWindow *tmaid,
 
 /******************************************************************************
 *                                                                             *
-* ja:ץؿ                                                 *
+* ja:ジャンプダイアログ関数群                                                 *
 *                                                                             *
 ******************************************************************************/
 static gboolean jump_clicked_ok;
 static GtkWidget *dialog, *button0, *entry;
 
 
-/* ja:OKܥ󤬲줿 */
+/* ja:OKボタンが押された */
 static void
 jump_dialog_clicked (GtkWidget  *widget,
                      JumpDialog *jmp)
@@ -104,7 +104,7 @@ jump_dialog_clicked (GtkWidget  *widget,
 }
 
 
-/* ja:ȥ꡼ǥ꥿󤬲줿 */
+/* ja:エントリーでリターンが押された */
 static void
 jump_dialog_activate (GtkWidget  *widget,
                       JumpDialog *jmp)
@@ -118,7 +118,7 @@ jump_dialog_activate (GtkWidget  *widget,
 }
 
 
-/* ja:ȥ꡼ѹ줿 */
+/* ja:エントリーが変更された */
 static void
 jump_dialog_changed (GtkWidget  *widget,
                      JumpDialog *jmp)
@@ -131,7 +131,7 @@ jump_dialog_changed (GtkWidget  *widget,
 }
 
 
-/* ja:ESC줿 */
+/* ja:ESCが押された */
 static gboolean
 jump_dialog_key_press (GtkWidget   *widget,
                        GdkEventKey *event,
@@ -143,8 +143,8 @@ jump_dialog_key_press (GtkWidget   *widget,
 }
 
 
-/*  ja:ץɽ
-    jmp,׾
+/*  ja:ジャンプダイアログ表示
+    jmp,ジャンプ情報
     RET,TRUE:OK,FALSE:Cancel                                                */
 gboolean
 jump_dialog (JumpDialog *jmp)
@@ -152,14 +152,14 @@ jump_dialog (JumpDialog *jmp)
   gchar *text;
   GtkWidget *button1, *hbox, *vbox;
 
-  /* ja:ᥤ󥦥ɥ */
+  /* ja:メインウインドウ */
   dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (dialog), _("Jump"));
   g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
                                     G_CALLBACK (jump_dialog_key_press), NULL);
   g_signal_connect (G_OBJECT (dialog), "destroy", 
                                             G_CALLBACK (gtk_main_quit), NULL);
-  /* ja:ܥ */
+  /* ja:ボタン */
   button0 = gtk_button_new_with_label (_("OK"));
   button1 = gtk_button_new_with_label (_("Cancel"));
   g_signal_connect (G_OBJECT (button0), "clicked",
@@ -168,7 +168,7 @@ jump_dialog (JumpDialog *jmp)
                         G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
   GTK_WIDGET_SET_FLAGS (button0, GTK_CAN_DEFAULT);
   GTK_WIDGET_SET_FLAGS (button1, GTK_CAN_DEFAULT);
-  /* ja:ȥ꡼ */
+  /* ja:エントリー */
   entry = gtk_entry_new ();
   text = misc_str_from_val (jmp->cursor, 10, 0, FALSE);
   gtk_entry_set_text (GTK_ENTRY (entry), text);
@@ -178,7 +178,7 @@ jump_dialog (JumpDialog *jmp)
   g_signal_connect (G_OBJECT (entry), "changed",
                                     G_CALLBACK (jump_dialog_changed), jmp);
   gtk_editable_select_region (GTK_EDITABLE (entry), 0, -1);
-  /* ja:ե졼ȥܥå */
+  /* ja:フレームとボックス */
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), entry, TRUE, TRUE, 0);
@@ -188,7 +188,7 @@ jump_dialog (JumpDialog *jmp)
   gtk_box_pack_end (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
   gtk_container_add (GTK_CONTAINER (dialog), vbox);
 
-  /* ja:ɽ */
+  /* ja:表示 */
   gtk_widget_set_sensitive (button0, FALSE);
   gtk_widget_grab_focus (entry);
   jump_clicked_ok = FALSE;
