@@ -23,6 +23,11 @@
 #include "tmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 typedef struct JumpDialog_Tag
 {
   gint cursor,max;
@@ -53,4 +58,9 @@ jump_operation (TmaidWindow *tmaid,
 gboolean jump_dialog(JumpDialog *jmp);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
