@@ -27,7 +27,7 @@
 #endif /* not G_OS_WIN32 */
 #include "misc/misc.h"
 #ifdef G_OS_WIN32
-# include "misc/misc_mdi.h"
+# include "orz/orzmdi.h"
 # include <gdk/gdkwin32.h>
 #endif /* G_OS_WIN32 */
 
@@ -118,8 +118,8 @@ print_out (TmaidWindow *tmaid,
     }
   g_memset (&di, 0, sizeof (DOCINFO));
   di.cbSize = sizeof (DOCINFO);
-  utf8str = g_filename_to_utf8 (misc_mdi_get_file (MISC_MDI (mdi),
-                        misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid)),
+  utf8str = g_filename_to_utf8 (orz_mdi_get_file (ORZ_MDI (mdi),
+                        orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid)),
                                                         -1, NULL, NULL, NULL);
 # ifdef UNICODE
   name = g_utf8_to_utf16 (utf8str, -1, NULL, NULL, NULL);
@@ -608,10 +608,13 @@ static void
 print_dialog_clicked_file (GtkWidget   *widget,
                            PrintConfig *prncfg)
 {
-  gchar *file = NULL;
   GtkWidget *dialog_open;
 
 # if GTK_CHECK_VERSION(2,4,0)
+  gchar *file;
+  gint i;
+  GtkFileFilter *filter;
+
   dialog_open = gtk_file_chooser_dialog_new (_("Save As"),
                         GTK_WINDOW (window), GTK_FILE_CHOOSER_ACTION_SAVE,
                         GTK_STOCK_SAVE_AS, GTK_RESPONSE_ACCEPT,
@@ -636,10 +639,37 @@ print_dialog_clicked_file (GtkWidget   *widget,
       g_free (path);
     }
   g_free (file);
-  file = gtk_dialog_run (GTK_DIALOG (dialog_open)) == GTK_RESPONSE_ACCEPT
-    ? gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog_open)) : NULL;
+  /* ja:フィルタの設定 */
+  for (i = 0; i < ftnum; i++)
+    {
+      gchar **ext;
+      gint j;
+
+      filter = gtk_file_filter_new ();
+      gtk_file_filter_set_name (filter, ftype[i].text);
+      ext = g_strsplit (ftype[i].ext, G_SEARCHPATH_SEPARATOR_S, G_MAXINT);
+      for (j = 0; ext[j]; j++)
+        gtk_file_filter_add_pattern (filter, ext[j]);
+      g_strfreev (ext);
+      gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog_open), filter);
+      if (i == findex)
+        gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog_open), filter);
+      g_object_set_data (G_OBJECT (filter), "user_data", (gpointer)i);
+    }
+  if (gtk_dialog_run (GTK_DIALOG (dialog_open)) == GTK_RESPONSE_ACCEPT)
+    {
+      file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog_open));
+      filter = gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog_open));
+      findex = (gint)g_object_get_data (G_OBJECT (filter), "user_data");
+    }
+  else
+    {
+      file = NULL;
+    }
   gtk_widget_destroy (dialog_open);
 # else /* not GTK_CHECK_VERSION(2,4,0) */
+  gchar *file = NULL;
+
   dialog_open = gtk_file_selection_new (_("Save As"));
   g_signal_connect (G_OBJECT (dialog_open), "destroy",
                                             G_CALLBACK (gtk_main_quit), NULL);
