@@ -22,7 +22,7 @@
 #include "general.h"
 #include "sigfile.h"
 #include "misc/misc.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -42,7 +42,7 @@ signal_timeout (gpointer data)
       GdkRectangle rc;
       TmaidWindow *tmaid;
 
-      tmaid = misc_mdi_get_data (MISC_MDI (mdi), page);
+      tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page);
       rc.x = (edit_get_align_pos (tmaid, tmaid->cursor.x,
                 tmaid->cursor.y, FALSE) - tmaid->top.x) * tmaid->font_width;
       rc.y = (tmaid->cursor.y - tmaid->top.y) * tmaid->font_height;
@@ -200,7 +200,7 @@ signal_destroy_draw (GtkWidget   *widget,
                      TmaidWindow *tmaid)
 {
   /* ja:メニュー */
-  if (misc_mdi_get_n_pages (MISC_MDI (mdi)) <= 1)
+  if (orz_mdi_get_n_pages (ORZ_MDI (mdi)) <= 1)
     {
       set_menu_bar (NULL);
       gtk_statusbar_pop (GTK_STATUSBAR (status),
@@ -278,8 +278,8 @@ signal_commit (GtkIMContext *im_context,
       tmaid->undo = d;
       if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
         set_menu_bar (tmaid);
-      misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
+      orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid), TRUE);
     }
 #ifndef G_OS_WIN32
   gtk_im_context_get_preedit_string (im_context, &str, NULL, NULL);
@@ -797,8 +797,8 @@ signal_button_press (GtkWidget      *widget,
                     if (delete_list(&tmaid->redo) > 0 || !d->next
                                                                 || select.x<0)
                       set_menu_bar (tmaid);
-                    misc_mdi_set_edited (MISC_MDI (mdi),
-                        misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid),
+                    orz_mdi_set_edited (ORZ_MDI (mdi),
+                            orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid),
                                                                         TRUE);
                   }
                 else
@@ -813,24 +813,22 @@ signal_button_press (GtkWidget      *widget,
               {
                 GtkWidget *menu_shell, *menu_item;
 
-                menu_item = gtk_item_factory_get_item (ifactory_popup,
-                                                    "<main>/Input Methods");
+                menu_item = misc_find_menu (popup_entries, "/input");
                 gtk_menu_item_remove_submenu (GTK_MENU_ITEM (menu_item));
                 menu_shell = gtk_menu_new ();
                 gtk_im_multicontext_append_menuitems (GTK_IM_MULTICONTEXT
                             (tmaid->im_context), GTK_MENU_SHELL (menu_shell));
                 gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item),
                                                                 menu_shell);
-                gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                    (ifactory_popup, "<main>/Undo"), tmaid->undo != NULL);
-                gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                    (ifactory_popup, "<main>/Cut"), tmaid->select.x >= 0);
-                gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                    (ifactory_popup, "<main>/Copy"), tmaid->select.x >= 0);
-                gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                    (ifactory_popup, "<main>/Delete"), tmaid->select.x >= 0);
-                gtk_menu_popup (GTK_MENU
-                    (gtk_item_factory_get_widget (ifactory_popup,"<main>")),
+                gtk_widget_set_sensitive (misc_find_menu (popup_entries,
+                                            "/undo"), tmaid->undo != NULL);
+                gtk_widget_set_sensitive (misc_find_menu (popup_entries,
+                                            "/cut"), tmaid->select.x >= 0);
+                gtk_widget_set_sensitive (misc_find_menu (popup_entries,
+                                            "/copy"), tmaid->select.x >= 0);
+                gtk_widget_set_sensitive (misc_find_menu (popup_entries,
+                                            "/delete"), tmaid->select.x >= 0);
+                gtk_menu_popup (GTK_MENU (misc_find_menu (popup_entries, "/")),
                         NULL, NULL, NULL, NULL, event->button, event->time);
               }
           }
