@@ -25,8 +25,8 @@
 #include "sigmain.h"
 #include "misc/argument.h"
 #include "misc/misc.h"
-#include "misc/misc_history.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzhistory.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -59,11 +59,11 @@ signal_style_set (GtkWidget *widget,
   system_font = pango_font_description_copy
                                     (pango_context_get_font_description
                                     (gtk_widget_get_pango_context (widget)));
-  for (i = misc_mdi_get_n_pages (MISC_MDI (mdi)) - 1; i >= 0; i--)
+  for (i = orz_mdi_get_n_pages (ORZ_MDI (mdi)) - 1; i >= 0; i--)
     {
       TmaidWindow *tmaid;
 
-      tmaid = misc_mdi_get_data (MISC_MDI (mdi), i);
+      tmaid = orz_mdi_get_data (ORZ_MDI (mdi), i);
       if (tmaid->ft.syscol || !tmaid->ft.font_name)
         {
           if (!tmaid->ft.font_name)
@@ -266,7 +266,7 @@ signal_selection_received (GtkWidget        *widget,
           TmaidHistory *d;
 
           page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-          tmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
+          tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
           select = tmaid->select;
           d = edit_operation (tmaid, text, g_strlen (text),
                             data->selection == GDK_SELECTION_CLIPBOARD, FALSE);
@@ -274,7 +274,7 @@ signal_selection_received (GtkWidget        *widget,
           tmaid->undo = d;
           if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
             set_menu_bar (tmaid);
-          misc_mdi_set_edited (MISC_MDI (mdi), page_num, TRUE);
+          orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
           g_free (text);
         }
     }
@@ -301,8 +301,8 @@ signal_selection_recv (GObject   *object,
 
   /* ja:プロセス間通信 */
   /* ja:ファイルの履歴 */
-  arg_h.val = misc_history_get_num (MISC_HISTORY (history));
-  arg_h.def = MISC_HISTORY_NUM_DEF;
+  arg_h.val = orz_history_get_num (ORZ_HISTORY (history));
+  arg_h.def = ORZ_HISTORY_NUM_DEF;
   /* ja:初期のキャレット位置 */
   arg_l.val = 0;
   arg_l.def = 0;
@@ -322,7 +322,7 @@ signal_selection_recv (GObject   *object,
   arg_x.def = FALSE;
   /* ja:コマンドラインの解析 */
   arg_files = arg_analyse (argv, arg_opts);
-  misc_history_set_num (MISC_HISTORY (history), arg_h.val);
+  orz_history_set_num (ORZ_HISTORY (history), arg_h.val);
   newfile = arg_n.flag;
   def_width = array[0];
   def_height = array[1];
@@ -355,7 +355,7 @@ signal_delete (GtkWidget *widget,
   while ((page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi))) >= 0)
     {
       if (!prompt_close ((TmaidWindow *)
-                                    misc_mdi_get_data (MISC_MDI (mdi), page)))
+                                    orz_mdi_get_data (ORZ_MDI (mdi), page)))
         return TRUE;
       gtk_notebook_remove_page (GTK_NOTEBOOK (mdi), page);
     }
